/* EidosUI CSS Variables - Base Configuration */

:root {
    /* Core Colors */
    --color-primary: #3b82f6;
    --color-primary-hover: #2563eb;
    --color-primary-light: #dbeafe;
    --color-primary-dark: #1d4ed8;
    --color-primary-foreground: #ffffff;
    
    --color-secondary: #6b7280;
    --color-secondary-hover: #4b5563;
    --color-secondary-light: #f9fafb;
    --color-secondary-dark: #374151;
    --color-secondary-foreground: #ffffff;
    
    --color-accent: #7c3aed;
    --color-accent-hover: #6d28d9;
    --color-accent-light: #f3e8ff;
    --color-accent-dark: #5b21b6;
    --color-accent-foreground: #ffffff;
    
    /* Semantic Colors */
    --color-success: #10b981;
    --color-success-hover: #059669;
    --color-success-light: #d1fae5;
    --color-success-dark: #047857;
    --color-success-foreground: #ffffff;
    
    --color-cta: #f59e0b;
    --color-cta-hover: #d97706;
    --color-cta-light: #fef3c7;
    --color-cta-dark: #b45309;
    --color-cta-foreground: #ffffff;
    
    --color-warning: #eab308;
    --color-warning-hover: #ca8a04;
    --color-warning-light: #fefce8;
    --color-warning-dark: #a16207;
    --color-warning-foreground: #000000;
    
    --color-error: #dc2626;
    --color-error-hover: #b91c1c;
    --color-error-light: #fef2f2;
    --color-error-dark: #991b1b;
    --color-error-foreground: #ffffff;
    
    --color-info: #0ea5e9;
    --color-info-hover: #0284c7;
    --color-info-light: #f0f9ff;
    --color-info-dark: #0369a1;
    --color-info-foreground: #ffffff;
    
    /* Surface Colors */
    --color-background: #ffffff;
    --color-surface: #f8fafc;
    --color-surface-elevated: #ffffff;
    --color-border: #e2e8f0;
    --color-border-hover: #cbd5e1;
    --color-input: #ffffff;
    --color-card: #ffffff;
    
    /* Text Colors */
    --color-text: #0f172a;
    --color-text-muted: #64748b;
    --color-text-subtle: #94a3b8;
    --color-text-inverse: #ffffff;
    
    /* RGB Values for Gradients (without rgb() wrapper) */
    --color-primary-rgb: 59, 130, 246;
    --color-secondary-rgb: 156, 163, 175;
    --color-accent-rgb: 168, 85, 247;
    --color-surface-rgb: 248, 250, 252;
    --color-background-rgb: 255, 255, 255;
    --color-error-rgb: 220, 38, 38;
    --color-success-rgb: 16, 185, 129;
    
    /* Spacing Scale */
    --space-xs: 0.25rem;   /* 4px */
    --space-sm: 0.5rem;    /* 8px */
    --space-md: 1rem;      /* 16px */
    --space-lg: 1.5rem;    /* 24px */
    --space-xl: 2rem;      /* 32px */
    --space-2xl: 3rem;     /* 48px */
    --space-3xl: 4rem;     /* 64px */
    
    /* Typography Scale */
    --font-size-xs: 0.75rem;    /* 12px */
    --font-size-sm: 0.875rem;   /* 14px */
    --font-size-base: 1rem;     /* 16px */
    --font-size-lg: 1.125rem;   /* 18px */
    --font-size-xl: 1.25rem;    /* 20px */
    --font-size-2xl: 1.5rem;    /* 24px */
    --font-size-3xl: 1.875rem;  /* 30px */
    --font-size-4xl: 2.25rem;   /* 36px */
    --font-size-5xl: 3rem;      /* 48px */
    --font-size-6xl: 3.75rem;   /* 60px */
    
    /* Font Weights */
    --font-weight-thin: 100;
    --font-weight-light: 300;
    --font-weight-normal: 400;
    --font-weight-medium: 500;
    --font-weight-semibold: 600;
    --font-weight-bold: 700;
    --font-weight-extrabold: 800;
    --font-weight-black: 900;
    
    /* Line Heights */
    --line-height-none: 1;
    --line-height-tight: 1.25;
    --line-height-snug: 1.375;
    --line-height-normal: 1.5;
    --line-height-relaxed: 1.625;
    --line-height-loose: 2;
    
    /* Letter Spacing */
    --letter-spacing-tighter: -0.05em;
    --letter-spacing-tight: -0.025em;
    --letter-spacing-normal: 0em;
    --letter-spacing-wide: 0.025em;
    --letter-spacing-wider: 0.05em;
    --letter-spacing-widest: 0.1em;
    
    /* Border Radius */
    --radius-none: 0;
    --radius-sm: 0.125rem;   /* 2px */
    --radius-base: 0.25rem;  /* 4px */
    --radius-md: 0.375rem;   /* 6px */
    --radius-lg: 0.5rem;     /* 8px */
    --radius-xl: 0.75rem;    /* 12px */
    --radius-2xl: 1rem;      /* 16px */
    --radius-3xl: 1.5rem;    /* 24px */
    --radius-full: 9999px;
    
    /* Border Width */
    --border-0: 0px;
    --border: 1px;
    --border-2: 2px;
    --border-4: 4px;
    --border-8: 8px;
    
    /* Shadows */
    --shadow-xs: 0 1px 2px 0 rgb(0 0 0 / 0.05);
    --shadow-sm: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);
    --shadow-base: 0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);
    --shadow-md: 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);
    --shadow-lg: 0 20px 25px -5px rgb(0 0 0 / 0.1), 0 8px 10px -6px rgb(0 0 0 / 0.1);
    --shadow-xl: 0 25px 50px -12px rgb(0 0 0 / 0.25);
    --shadow-2xl: 0 30px 60px -15px rgb(0 0 0 / 0.3);
    --shadow-inner: inset 0 2px 4px 0 rgb(0 0 0 / 0.05);
    --shadow-none: none;
    
    /* Opacity */
    --opacity-0: 0;
    --opacity-5: 0.05;
    --opacity-10: 0.1;
    --opacity-20: 0.2;
    --opacity-25: 0.25;
    --opacity-30: 0.3;
    --opacity-40: 0.4;
    --opacity-50: 0.5;
    --opacity-60: 0.6;
    --opacity-70: 0.7;
    --opacity-75: 0.75;
    --opacity-80: 0.8;
    --opacity-90: 0.9;
    --opacity-95: 0.95;
    --opacity-100: 1;
    
    /* Animation */
    --transition-fast: 150ms ease;
    --transition-base: 200ms ease;
    --transition-slow: 300ms ease;
    --transition-slower: 500ms ease;
    
    /* Z-index */
    --z-index-0: 0;
    --z-index-10: 10;
    --z-index-20: 20;
    --z-index-30: 30;
    --z-index-40: 40;
    --z-index-50: 50;
    --z-index-auto: auto;
    
    /* Breakpoints (for reference in JavaScript) */
    --breakpoint-sm: 640px;
    --breakpoint-md: 768px;
    --breakpoint-lg: 1024px;
    --breakpoint-xl: 1280px;
    --breakpoint-2xl: 1536px;
    
    /* Form-specific Variables */
    --form-input-height: 2.5rem;  /* 40px */
    --form-input-padding-x: var(--space-md);
    --form-input-padding-y: var(--space-sm);
    --form-input-border-width: var(--border);
    --form-input-border-color: var(--color-border);
    --form-input-border-color-hover: var(--color-border-hover);
    --form-input-border-color-focus: var(--color-primary);
    --form-input-bg: var(--color-input);
    --form-input-bg-disabled: var(--color-surface);
    --form-input-text: var(--color-text);
    --form-input-text-disabled: var(--color-text-muted);
    --form-input-placeholder: var(--color-text-subtle);
    --form-input-radius: var(--radius-md);
    --form-input-shadow: var(--shadow-xs);
    --form-input-shadow-focus: 0 0 0 3px rgba(var(--color-primary-rgb), 0.1);
    
    --form-label-font-size: var(--font-size-sm);
    --form-label-font-weight: var(--font-weight-medium);
    --form-label-color: var(--color-text);
    --form-label-margin-bottom: var(--space-xs);
    
    --form-help-font-size: var(--font-size-sm);
    --form-help-color: var(--color-text-muted);
    --form-help-margin-top: var(--space-xs);
    
    --form-error-color: var(--color-error);
    --form-error-border-color: var(--color-error);
    --form-error-bg: var(--color-error-light);
    --form-error-font-size: var(--font-size-sm);
    
    --form-fieldset-border: var(--border) solid var(--color-border);
    --form-fieldset-padding: var(--space-lg);
    --form-fieldset-radius: var(--radius-lg);
    --form-fieldset-bg: var(--color-surface);
    
    --form-checkbox-size: 1.25rem;  /* 20px */
    --form-radio-size: 1.25rem;  /* 20px */
    --form-checkbox-bg: var(--color-background);
    --form-checkbox-bg-checked: var(--color-primary);
    --form-checkbox-border: var(--color-border);
    --form-checkbox-check-color: var(--color-primary-foreground);
    
    /* Date/Time Picker Variables */
    --form-datetime-bg: var(--color-background);
    --form-datetime-text: var(--color-text);
    --form-datetime-border: var(--color-border);
    --form-datetime-button-bg: var(--color-surface);
    --form-datetime-button-hover: var(--color-border);
    --form-datetime-icon-color: var(--color-text-muted);
  }