/* EidosUI Light Theme */
/* Default theme - these values are already defined in eidos-variables.css */
/* This file exists for explicit light theme selection and future customization */

[data-theme="light"] {
    /* Core Colors */
    --color-primary: #3b82f6;
    --color-primary-hover: #2563eb;
    --color-primary-light: #dbeafe;
    --color-primary-dark: #1d4ed8;
    --color-primary-foreground: #ffffff;
    
    --color-secondary: #6b7280;
    --color-secondary-hover: #4b5563;
    --color-secondary-light: #f9fafb;
    --color-secondary-dark: #374151;
    --color-secondary-foreground: #ffffff;
    
    --color-accent: #7c3aed;
    --color-accent-hover: #6d28d9;
    --color-accent-light: #f3e8ff;
    --color-accent-dark: #5b21b6;
    --color-accent-foreground: #ffffff;
    
    /* Semantic Colors */
    --color-success: #10b981;
    --color-success-hover: #059669;
    --color-success-light: #d1fae5;
    --color-success-dark: #047857;
    --color-success-foreground: #ffffff;
    
    --color-cta: #f59e0b;
    --color-cta-hover: #d97706;
    --color-cta-light: #fef3c7;
    --color-cta-dark: #b45309;
    --color-cta-foreground: #ffffff;
    
    --color-warning: #eab308;
    --color-warning-hover: #ca8a04;
    --color-warning-light: #fefce8;
    --color-warning-dark: #a16207;
    --color-warning-foreground: #000000;
    
    --color-error: #dc2626;
    --color-error-hover: #b91c1c;
    --color-error-light: #fef2f2;
    --color-error-dark: #991b1b;
    --color-error-foreground: #ffffff;
    
    --color-info: #0ea5e9;
    --color-info-hover: #0284c7;
    --color-info-light: #f0f9ff;
    --color-info-dark: #0369a1;
    --color-info-foreground: #ffffff;
    
    /* Surface Colors */
    --color-background: #ffffff;
    --color-surface: #f8fafc;
    --color-surface-elevated: #ffffff;
    --color-border: #e2e8f0;
    --color-border-hover: #cbd5e1;
    --color-input: #ffffff;
    --color-card: #ffffff;
    
    /* Text Colors */
    --color-text: #0f172a;
    --color-text-muted: #64748b;
    --color-text-subtle: #94a3b8;
    --color-text-inverse: #ffffff;
    
    /* Shadows - Light Theme */
    --shadow-xs: 0 1px 2px 0 rgb(0 0 0 / 0.05);
    --shadow-sm: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);
    --shadow-base: 0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);
    --shadow-md: 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);
    --shadow-lg: 0 20px 25px -5px rgb(0 0 0 / 0.1), 0 8px 10px -6px rgb(0 0 0 / 0.1);
    --shadow-xl: 0 25px 50px -12px rgb(0 0 0 / 0.25);
    --shadow-2xl: 0 30px 60px -15px rgb(0 0 0 / 0.3);
    --shadow-inner: inset 0 2px 4px 0 rgb(0 0 0 / 0.05);
  }